import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
const _excluded = ["className", "frameClass", "theme", "language", "children"];
// eslint-disable-next-line import/no-extraneous-dependencies
import React, { useMemo, memo, useState, useEffect, useRef } from 'react';
import classNames from 'classnames';
import copy from 'copy-to-clipboard';
import SyntaxHighlighter from 'react-syntax-highlighter/dist/esm/prism-light';
import tsxSyntax from 'react-syntax-highlighter/dist/esm/languages/prism/tsx';
import defaultTheme from 'react-syntax-highlighter/dist/esm/styles/prism/vsc-dark-plus';
import styles from "./codeSnippet.module.scss";
import IconCopy from "../asset/icon-copy.svg";
import IconCheck from "../asset/icon-check.svg";
import IconShrink from "../asset/icon-shrink.svg";
import IconExpand from "../asset/icon-expand.svg";
SyntaxHighlighter.registerLanguage('tsx', tsxSyntax);
const customStyles = {
  fontSize: 12
};
const Highlighter = /*#__PURE__*/memo(function SnippetWrapper(props) {
  return /*#__PURE__*/React.createElement(SyntaxHighlighter, props);
});

/**
 * A code snippet component
 */
export function CodeSnippet(_ref) {
  let {
      className,
      frameClass,
      theme = defaultTheme,
      language = 'tsx',
      children
    } = _ref,
    rest = _objectWithoutProperties(_ref, _excluded);
  const [codeCopied, setCodeCopied] = useState(false);
  const [codeExpanded, setCodeExpanded] = useState(false);
  const refResetCopyStatusTimer = useRef(null);
  const trimmedChildren = useMemo(() => children.trim(), [children]);
  useEffect(() => {
    clearTimeout(refResetCopyStatusTimer.current);
    refResetCopyStatusTimer.current = setTimeout(() => {
      setCodeCopied(false);
    }, 1000);
  }, [codeCopied]);
  useEffect(() => {
    return () => {
      clearTimeout(refResetCopyStatusTimer.current);
    };
  }, []);
  return /*#__PURE__*/React.createElement("div", {
    className: classNames(styles.snippetWrapper, className)
  }, /*#__PURE__*/React.createElement(Highlighter, _extends({}, rest, {
    className: classNames(styles.codeSnippet, frameClass, {
      [styles.expanded]: codeExpanded
    }),
    language: language,
    style: theme,
    customStyle: customStyles
  }), trimmedChildren), /*#__PURE__*/React.createElement("div", {
    className: styles.operationButtons
  }, /*#__PURE__*/React.createElement("button", {
    onClick: () => {
      const result = copy(children.toString());
      setCodeCopied(result);
    }
  }, codeCopied ? /*#__PURE__*/React.createElement(IconCheck, null) : /*#__PURE__*/React.createElement(IconCopy, null)), /*#__PURE__*/React.createElement("button", {
    onClick: () => setCodeExpanded(!codeExpanded)
  }, codeExpanded ? /*#__PURE__*/React.createElement(IconShrink, null) : /*#__PURE__*/React.createElement(IconExpand, null))));
}